Learn R Programming

ghypernet (version 1.1.2)

coef.nrm: Extraction method for coefficients of models of class 'nrm'.

Description

Extraction method for coefficients of models of class 'nrm'.

Usage

# S3 method for nrm
coef(object, ...)

Value

coefficients of nrm model.

Arguments

object

object of class 'nrm'.

...

optional arguments to print methods.

Author

Giona Casiraghi

See Also

nrm