Learn R Programming

ghypernet (version 1.1.2)

compute_xi: Auxiliary function. Computes combinatorial matrix.

Description

Combinatorial matrix computed according to soft configuration model or 'regular' gnp model.

Usage

compute_xi(adj, directed, selfloops, regular = FALSE)

ComputeXi(adj, directed, selfloops, regular = FALSE)

Value

combinatorial matrix

Arguments

adj

adjacency matrix

directed

boolean, whether the model is for a directed network

selfloops

boolean, whether the model contains selfloops

regular

boolean. Is the combinatorial matrix computed for configuration model or for regular gnp model? default FALSE.

Examples

Run this code
data('adj_karate')
xi = compute_xi(adj_karate, directed = FALSE, selfloops = FALSE)

Run the code above in your browser using DataLab