Extract details from statistical models for table construction. The function has methods for a range of statistical models.
extract.nrm.cluster(model, ...)The function returns a texreg object.
A statistical model object.
Custom parameters, which are handed over to subroutines. The arguments are usually passed to the summary function, but in some cases to other functions.
L. Brandenberger, G. Casiraghi